[![CircleCI](https://circleci.com/gh/yamsergey/rikki.svg?style=svg&circle-token=a3ff3d7f5da08b8af00e14b5f704d375855f5685)](https://circleci.com/gh/yamsergey/rikki) [![PyPI version](https://badge.fury.io/py/rikki.svg)](https://badge.fury.io/py/rikki)

# Rikki - complicated testing environment 

This project it's set of tools and utilities which allow to run behavioral tests backed up by a proxy. The configuration allows to tests things that couldn't be automated before:

- Ads implementations 
- In-app Tracking
- GDPR complaints
- And more

## Dependencies 
Currently the project use Behave and Mitmproxy.


